@@ -43,8 +43,6 @@ from typedpy.fields import (
     String,
     SizedString,
     Sized,
-    Enum,
-    EnumString,
     AllOf,
     AnyOf,
     OneOf,
@@ -78,6 +76,8 @@ from typedpy.json_schema_mapping import (
     write_code_from_schema,
 )
 
+from .enum import Enum, EnumString
+
 from .serialization import (
     deserialize_structure,
     serialize,
@@ -113,6 +113,6 @@ from .mappers import mappers, Deleted, Constant, DoNotSerialize
 
 from .versioned_mapping import convert_dict, Versioned
 
-from .commons import nested, deep_get, first_in, flatten
+from .commons import nested, deep_get, first_in, flatten, default_factories
 
 from .keysof import keys_of
\ No newline at end of file
